# coding: utf-8

from __future__ import unicode_literals
from __future__ import print_function
from __future__ import absolute_import
from __future__ import division
from django.db import models
from generic_helpers.models import (GenericRelationModel as GRM,
                                    generic_relation_factory)


STORY_NUMBER = 5
PICTURE_NUMBER = 4
COMMENT_NUMBER = 3
VOTING_CT_NAME = 'buzz'


BuzzGRM = generic_relation_factory(gr_field=VOTING_CT_NAME)


class Story(models.Model):
    text = models.TextField()

    class Meta(object):
        app_label = 'generic_helpers'


class Picture(models.Model):
    url = models.URLField(max_length=255)

    class Meta(object):
        app_label = 'generic_helpers'


class Comment(GRM):
    body = models.TextField(max_length=255)

    class Meta(object):
        app_label = 'generic_helpers'


class Voting(BuzzGRM):
    score = models.IntegerField(default=1)

    class Meta(object):
        app_label = 'generic_helpers'



# coding: utf-8

from __future__ import unicode_literals
from __future__ import print_function
from __future__ import absolute_import
from __future__ import division
from django.contrib import admin


class GenericRelationModelAdmin(admin.ModelAdmin):
    pass



#!/usr/bin/env python
# coding: utf-8

from setuptools import setup, find_packages
import os

version = __import__('generic_helpers').get_version()


DIR = os.path.dirname(__file__)
DOWNLOAD_URL = ('https://github.com/marazmiki/django-generic-helpers/'
                'archive/master.zip')


CLASSIFIERS = [
    'Development Status :: 4 - Beta',
    'Environment :: Web Environment',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
    'Framework :: Django'
]


def long_description():
    """
    Returns package long description from README
    """
    def read(what):
        with open(os.path.join(DIR, '%s.rst' % what)) as fp:
            return fp.read()

    return "{README}\n\n{CHANGELOG}".format(README=read('README'),
                                            CHANGELOG=read('CHANGELOG'))


setup(name='django-generic-helpers',
      author='Mikhail Porokhovnichenko <marazmiki@gmail.com>',
      version=version,
      author_email='marazmiki@gmail.com',
      url='https://github.com/marazmiki/django-generic-helpers',
      download_url=DOWNLOAD_URL,
      description=('The small frameworks that helps to write '
                   'reusable django apps with generic relations'),
      long_description=long_description(),
      license='MIT license',
      platforms=['OS Independent'],
      classifiers=CLASSIFIERS,
      install_requires=[
          'Django>=1.5',
      ],
      tests_require=[],
      test_suite='tests.main',
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False)



# coding: utf-8

from __future__ import unicode_literals
from __future__ import print_function
from __future__ import absolute_import
from __future__ import division
import sys


VERSION = (0, 3, 2)


def get_version():
    PY3 = sys.version_info[0] == 3

    if PY3:
        text_type = str
    else:
        text_type = unicode    # NOQA
    return '.'.join(map(text_type, VERSION))


__author__ = 'Mikhail Porokhovnichenko <marazmiki@gmail.com>'
__version__ = get_version()
